
DeNova Safelog
--------------

Get instant safe multithread, multiprocess, multiprogram logs.
Safelog also has a much simpler and more powerful api than standard python logging.


Learn more about DeNova Safelog at https://denova.com/open_source/safelog/
